import json
import pathlib

from data_inclusion.schema import (
    Frais,
    LabelNational,
    ModeAccueil,
    ModeOrientationAccompagnateur,
    ModeOrientationBeneficiaire,
    Profil,
    Service,
    Structure,
    Thematique,
    Typologie,
    TypologieService,
    ZoneDiffusionType,
)


def json_dump(obj, file):
    json.dump(
        obj,
        file,
        indent=2,
        ensure_ascii=False,
        sort_keys=True,
    )


def main():
    output_dir = pathlib.Path() / "schemas"
    output_dir.mkdir(exist_ok=True)

    for model in [Structure, Service]:
        with (output_dir / f"{model.__name__.lower()}.json").open("w") as file:
            json.dump(
                model.model_json_schema(),
                file,
                indent=2,
                ensure_ascii=False,
                sort_keys=True,
            )

    # fichiers supplémentaires documentant les énumérations

    (output_dir / "extra").mkdir(exist_ok=True)

    enum_x_file_tuples_list = [
        ("frais.json", Frais),
        ("labels-nationaux.json", LabelNational),
        ("modes-accueil.json", ModeAccueil),
        ("modes-orientation-accompagnateur.json", ModeOrientationAccompagnateur),
        ("modes-orientation-beneficiaire.json", ModeOrientationBeneficiaire),
        ("profils.json", Profil),
        ("thematiques.json", Thematique),
        ("typologies-de-services.json", TypologieService),
        ("typologies-de-structures.json", Typologie),
        ("zones-de-diffusion-types.json", ZoneDiffusionType),
    ]

    for filename, enum in enum_x_file_tuples_list:
        with (output_dir / "extra" / filename).open("w") as file:
            json_dump(enum.as_dict_list(), file)


if __name__ == "__main__":
    """
    Usage:
        $ python -m data_inclusion.schema
    """
    main()



from data_inclusion.schema.base import EnhancedEnum


class TypologieService(EnhancedEnum):
    ACCOMPAGNEMENT = (
        "accompagnement",
        "Accompagnement",
        "Etre accompagné·e dans ses démarches ou son retour à l’emploi durable",
    )
    ACCUEIL = (
        "accueil",
        "Accueil",
        """
            Lieux d’écoute et d’évaluation des besoins de la personne qui se présente
            afin de la guider vers le ou les organismes les plus susceptibles de
            répondre à ses besoins
        """,
    )
    AIDE_FINANCIERE = (
        "aide-financiere",
        "Aide financière",
        """
            Prise en charge financière, aide ou rémunération visant à aider une
            personne à accéder à un service
        """,
    )
    AIDE_MATERIELLE = (
        "aide-materielle",
        "Aide materielle",
        "Accéder à du matériel, voiture, vélo, ordinateur, alimentation",
    )
    ATELIER = (
        "atelier",
        "Atelier",
        "Etre accompagné·e dans sa montée en compétence sur un sujet spécifique",
    )
    FORMATION = (
        "formation",
        "Formation",
        "Formation dispensée par des professionnels pour les bénéficiaires",
    )
    INFORMATION = (
        "information",
        "Information",
        "Premier niveau d’information apporté par des professionnels du secteur",
    )
    NUMÉRIQUE = (
        "numerique",
        "Service numérique",
        "Service en ligne qui renvoi vers un site dédié",
    )
    AUTONOMIE = (
        "autonomie",
        "En autonomie",
        "Réaliser des démarches en toute autonomie",
    )
    DELEGATION = (
        "delegation",
        "Délégation",
        "Une personne fait les démarches à ma place.",
    )
    FINANCEMENT = (
        "financement",
        "Financement ",
        "Crédit solidaire, prêts à taux zéro pour le financement d’un projet",
    )



from data_inclusion.schema.base import EnhancedEnum


class ModeOrientationAccompagnateur(EnhancedEnum):
    COMPLETER_LE_FORMULAIRE_DADHESION = (
        "completer-le-formulaire-dadhesion",
        "Compléter le formulaire d’adhésion",
        "Compléter le formulaire d’adhésion associé.",
    )
    ENVOYER_UN_MAIL = (
        "envoyer-un-mail",
        "Envoyer un courriel",
        "Envoyer un courriel à l’adresse indiquée.",
    )
    ENVOYER_UN_MAIL_AVEC_UNE_FICHE_DE_PRESCRIPTION = (
        "envoyer-un-mail-avec-une-fiche-de-prescription",
        "Envoyer un courriel avec une fiche de prescription",
        "Envoyer un courriel à l’adresse indiquée avec une fiche de prescription.",
    )
    TELEPHONER = (
        "telephoner",
        "Téléphoner",
        "Téléphoner au numéro indiqué.",
    )
    PRENDRE_RDV = (
        "prendre-rdv",
        "Prendre rendez-vous",
        "Prendre rendez-vous auprès de la structure",
    )
    AUTRE = (
        "autre",
        "Autre",
        None,
    )


class ModeOrientationBeneficiaire(EnhancedEnum):
    COMPLETER_LE_FORMULAIRE_DADHESION = (
        "completer-le-formulaire-dadhesion",
        "Compléter le formulaire d’adhésion",
        "Compléter le formulaire d’adhésion associé.",
    )
    ENVOYER_UN_MAIL = (
        "envoyer-un-mail",
        "Envoyer un courriel",
        "Envoyer un courriel à l’adresse indiquée.",
    )
    SE_PRESENTER = (
        "se-presenter",
        "Se présenter",
        "Se présenter à l’adresse indiquée.",
    )
    TELEPHONER = (
        "telephoner",
        "Téléphoner",
        "Téléphoner au numéro indiqué.",
    )
    PRENDRE_RDV = (
        "prendre-rdv",
        "Prendre rendez-vous",
        "Prendre rendez-vous auprès de la structure",
    )
    AUTRE = (
        "autre",
        "Autre",
        None,
    )



from data_inclusion.schema.common import (
    CodeCommune,
    CodeDepartement,
    CodeEPCI,
    CodePostal,
    CodeRegion,
    CodeRna,
    CodeSiren,
    CodeSiret,
)
from data_inclusion.schema.frais import Frais
from data_inclusion.schema.labels_nationaux import LabelNational
from data_inclusion.schema.modes_accueil import ModeAccueil
from data_inclusion.schema.modes_orientation import (
    ModeOrientationAccompagnateur,
    ModeOrientationBeneficiaire,
)
from data_inclusion.schema.profils import Profil
from data_inclusion.schema.services import Service
from data_inclusion.schema.structures import Structure
from data_inclusion.schema.thematiques import Thematique
from data_inclusion.schema.typologies_de_services import TypologieService
from data_inclusion.schema.typologies_de_structures import Typologie
from data_inclusion.schema.zones_de_diffusion import ZoneDiffusionType

__all__ = [
    "CodeCommune",
    "CodeDepartement",
    "CodeEPCI",
    "CodePostal",
    "CodeRegion",
    "CodeRna",
    "CodeSiren",
    "CodeSiret",
    "Frais",
    "LabelNational",
    "ModeAccueil",
    "ModeOrientationAccompagnateur",
    "ModeOrientationBeneficiaire",
    "Profil",
    "Service",
    "Structure",
    "Thematique",
    "TypologieService",
    "Typologie",
    "ZoneDiffusionType",
]



from data_inclusion.schema.base import EnhancedEnum


class Typologie(EnhancedEnum):
    ACI = (
        "ACI",
        "Structures porteuses d’ateliers et chantiers d’insertion (ACI)",
        None,
    )
    ACIPHC = (
        "ACIPHC",
        "SIAE — Atelier chantier d’insertion premières heures en chantier",
        None,
    )
    AFPA = (
        "AFPA",
        "Agence nationale pour la formation professionnelle des adultes (AFPA)",
        None,
    )
    AI = (
        "AI",
        "Associations intermédiaires (AI)",
        None,
    )
    ASE = (
        "ASE",
        "Aide sociale à l’enfance (ASE)",
        None,
    )
    ASSO = (
        "ASSO",
        "Associations",
        None,
    )
    ASSO_CHOMEUR = (
        "ASSO_CHOMEUR",
        "Associations de chômeurs",
        None,
    )
    Autre = (
        "Autre",
        "Autre",
        None,
    )
    AVIP = (
        "AVIP",
        "Crèche À Vocation d’Insertion Professionnelle (AVIP)",
        None,
    )
    BIB = (
        "BIB",
        "Bibliothèque / Médiathèque",
        None,
    )
    CAARUD = (
        "CAARUD",
        (
            "CAARUD - Centre d’accueil et d’accompagnement à la réduction de risques "
            "pour usagers de drogues"
        ),
        None,
    )
    CADA = (
        "CADA",
        "Centres d’accueil de demandeurs d’asile (CADA)",
        None,
    )
    CAF = (
        "CAF",
        "Caisses d’allocation familiale (CAF)",
        None,
    )
    CAP_EMPLOI = (
        "CAP_EMPLOI",
        "Cap Emploi",
        None,
    )
    CAVA = (
        "CAVA",
        "Centres d’adaptation à la vie active (CAVA)",
        None,
    )
    CC = (
        "CC",
        "Communautés de Commune",
        None,
    )
    CCAS = (
        "CCAS",
        "Centres communaux d’action sociale (CCAS)",
        None,
    )
    CCONS = (
        "CCONS",
        "Chambres consulaires (CCI, CMA, CA)",
        None,
    )
    CD = (
        "CD",
        "Conseils Départementaux (CD)",
        None,
    )
    CDAS = (
        "CDAS",
        "Centre Départementale d'Action Sociale (CDAS)",
        None,
    )
    CFP = (
        "CFP",
        "Centre des Finances Publiques (CFP)",
        None,
    )
    CHRS = (
        "CHRS",
        "Centres d’hébergement et de réinsertion sociale (CHRS)",
        None,
    )
    CHU = (
        "CHU",
        "Centres d’hébergement d’urgence (CHU)",
        None,
    )
    CIAS = (
        "CIAS",
        "Centres intercommunaux d’action sociale (CIAS)",
        None,
    )
    CIDFF = (
        "CIDFF",
        "Centres d’information sur les droits des femmes et des familles (CIDFF)",
        None,
    )
    CITMET = (
        "CITMET",
        "Cité des métiers",
        None,
    )
    CMP = (
        "CMP",
        "Centre Médico-Psychologique (CMP)",
        None,
    )
    CMS = (
        "CMS",
        "Centre Médico-Social (CMS)",
        None,
    )
    CPAM = (
        "CPAM",
        "Caisse Primaire d'Assurance Maladie (CPAM)",
        None,
    )
    CPH = (
        "CPH",
        "Centres provisoires d’hébergement (CPH)",
        None,
    )
    CS = (
        "CS",
        "Centre social",
        None,
    )
    CSAPA = (
        "CSAPA",
        "CSAPA - Centre de soins, d’accompagnement et de prévention en addictologie",
        None,
    )
    CSC = (
        "CSC",
        "Centre Socio-Culturel (CSC)",
        None,
    )
    DEETS = (
        "DEETS",
        "Directions de l’Economie, de l’Emploi, du Travail et des Solidarités (DEETS)",
        None,
    )
    DEPT = (
        "DEPT",
        "Services sociaux du Conseil départemental",
        None,
    )
    DIPLP = (
        "DIPLP",
        (
            "Délégation interministérielles à la prévention et à la lutte contre la "
            "pauvreté"
        ),
        None,
    )
    E2C = (
        "E2C",
        "E2C - École de la 2e chance",
        None,
    )
    EA = (
        "EA",
        "Entreprise adaptée (EA)",
        None,
    )
    EATT = (
        "EATT",
        "Entreprise Adaptée (EATT)",
        None,
    )
    EI = (
        "EI",
        "Entreprises d’insertion (EI)",
        None,
    )
    EITI = (
        "EITI",
        "Entreprises d’insertion par le travail indépendant (EITI)",
        None,
    )
    ENM = (
        "ENM",
        "Espace Numérique Mobile (ENM)",
        None,
    )
    EPCI = (
        "EPCI",
        "Intercommunalité (EPCI)",
        None,
    )
    EPI = (
        "EPI",
        "Espace Public Internet (EPI)",
        None,
    )
    EPIDE = (
        "EPIDE",
        "EPIDE - Établissement pour l’insertion dans l’emploi",
        None,
    )
    EPN = (
        "EPN",
        "Espace Public Numérique (EPN)",
        None,
    )
    ES = (
        "ES",
        "Épicerie Solidaire",
        None,
    )
    ESS = (
        "ESS",
        "Entreprise de l’Économie Sociale et Solidaire",
        None,
    )
    ETABL_PRI = (
        "ETABL_PRI",
        "Établissement privé",
        None,
    )
    ETABL_PUB = (
        "ETABL_PUB",
        "Établissement public",
        None,
    )
    ETAT = (
        "ETAT",
        "Service de l'État",
        None,
    )
    ETTI = (
        "ETTI",
        "Entreprises de travail temporaire d’insertion (ETTI)",
        None,
    )
    EVS = (
        "EVS",
        "Espace de Vie Sociale (EVS)",
        None,
    )
    FABLAB = (
        "FABLAB",
        "Fablab / Atelier partagé",
        None,
    )
    FAIS = (
        "FAIS",
        "Fédérations d’acteurs de l’insertion et de la solidarité",
        None,
    )
    FT = (
        "FT",
        "France Travail",
        None,
    )
    GEIQ = (
        "GEIQ",
        "Groupements d’employeurs pour l’insertion et la qualification (GEIQ)",
        None,
    )
    HUDA = (
        "HUDA",
        "HUDA - Hébergement d’urgence pour demandeurs d’asile",
        None,
    )
    LA_POSTE = (
        "LA_POSTE",
        "Bureau de poste / Agence postale",
        None,
    )
    MDE = (
        "MDE",
        "Maison de l’emploi",
        None,
    )
    MDEF = (
        "MDEF",
        "Maison de l’emploi et de la formation",
        None,
    )
    MDPH = (
        "MDPH",
        "Maison Départementale des Personnes Handicapées",
        None,
    )
    MDS = (
        "MDS",
        "Maison Départementale des Solidarités",
        None,
    )
    MJC = (
        "MJC",
        "Maison des jeunes et de la culture",
        None,
    )
    ML = (
        "ML",
        "Mission Locale",
        None,
    )
    MQ = (
        "MQ",
        "Maison de quartier",
        None,
    )
    MSA = (
        "MSA",
        "Mutualité Sociale Agricole",
        None,
    )
    MSAP = (
        "MSAP",
        "Maison de Services Au Public (MSAP)",
        None,
    )
    MUNI = (
        "MUNI",
        "Municipalités",
        None,
    )
    OACAS = (
        "OACAS",
        (
            "Structures agréées Organisme d’accueil communautaire et d’activité "
            "solidaire (OACAS)"
        ),
        None,
    )
    ODC = (
        "ODC",
        "Organisation délégataire d’un CD",
        None,
    )
    OF = (
        "OF",
        "Organisme de formations",
        None,
    )
    OIL = (
        "OIL",
        "Opérateur d’intermédiation locative",
        None,
    )
    OPCS = (
        "OPCS",
        "Organisation porteuse de la clause sociale",
        None,
    )
    PAD = (
        "PAD",
        "Point d’Accès au Droit",
        None,
    )
    PENSION = (
        "PENSION",
        "Pension de famille / résidence accueil",
        None,
    )
    PI = (
        "PI",
        "Point Information (PI)",
        None,
    )
    PIJ_BIJ = (
        "PIJ_BIJ",
        "Points et bureaux information jeunesse (PIJ/BIJ)",
        None,
    )
    PIMMS = (
        "PIMMS",
        "Point Information Médiation Multi Services (PIMMS)",
        None,
    )
    PJJ = (
        "PJJ",
        "Protection judiciaire de la jeunesse (PJJ)",
        None,
    )
    PLIE = (
        "PLIE",
        "Plans locaux pour l’insertion et l’emploi (PLIE)",
        None,
    )
    PREF = (
        "PREF",
        "Préfecture, Sous-Préfecture",
        None,
    )
    PREVENTION = (
        "PREVENTION",
        "Service ou club de prévention",
        None,
    )
    REG = (
        "REG",
        "Région",
        None,
    )
    RESSOURCERIE = (
        "RESSOURCERIE",
        "Ressourcerie",
        None,
    )
    RFS = (
        "RFS",
        "Réseau France Services",
        None,
    )
    RS_FJT = (
        "RS_FJT",
        "Résidence sociale / FJT - Foyer de Jeunes Travailleurs",
        None,
    )
    SCP = (
        "SCP",
        "Services et clubs de prévention",
        None,
    )
    SPIP = (
        "SPIP",
        "Services pénitentiaires d’insertion et de probation (SPIP)",
        None,
    )
    TIERS_LIEUX = (
        "TIERS_LIEUX",
        "Tiers lieu & coworking",
        None,
    )
    UDAF = (
        "UDAF",
        "Union Départementale d’Aide aux Familles (UDAF)",
        None,
    )



from datetime import date, datetime
from typing import Annotated, Optional

from pydantic import EmailStr, HttpUrl, StringConstraints

from data_inclusion.schema import common
from data_inclusion.schema.base import BaseModel
from data_inclusion.schema.labels_nationaux import LabelNational
from data_inclusion.schema.thematiques import Thematique
from data_inclusion.schema.typologies_de_structures import Typologie


class Structure(BaseModel):
    # fields
    id: str
    siret: Optional[common.CodeSiret] = None
    rna: Optional[common.CodeRna] = None
    nom: str
    commune: Optional[str] = None
    code_postal: Optional[common.CodePostal] = None
    code_insee: Optional[common.CodeCommune] = None
    adresse: Optional[str] = None
    complement_adresse: Optional[str] = None
    longitude: Optional[float] = None
    latitude: Optional[float] = None
    typologie: Optional[Typologie] = None
    telephone: Optional[str] = None
    courriel: Optional[EmailStr] = None
    site_web: Optional[HttpUrl] = None
    presentation_resume: Optional[
        Annotated[str, StringConstraints(max_length=280)]
    ] = None
    presentation_detail: Optional[str] = None
    source: str
    date_maj: date | datetime
    antenne: Optional[bool] = None
    lien_source: Optional[HttpUrl] = None
    horaires_ouverture: Optional[str] = None
    accessibilite: Optional[HttpUrl] = None
    labels_nationaux: Optional[set[LabelNational]] = None
    labels_autres: Optional[set[str]] = None
    thematiques: Optional[set[Thematique]] = None



from typing import TypeAlias

from pydantic import StringConstraints
from typing_extensions import Annotated

CodePostal: TypeAlias = Annotated[
    str,
    StringConstraints(min_length=5, max_length=5, pattern=r"^\d{5}$"),
]

CodeRna: TypeAlias = Annotated[
    str,
    StringConstraints(min_length=10, max_length=10, pattern=r"^W\d{9}$"),
]

CodeSiren: TypeAlias = Annotated[
    str,
    StringConstraints(min_length=9, max_length=9, pattern=r"^\d{9}$"),
]

CodeSiret: TypeAlias = Annotated[
    str,
    StringConstraints(min_length=14, max_length=14, pattern=r"^\d{14}$"),
]

CodeCommune: TypeAlias = Annotated[
    str,
    StringConstraints(min_length=5, max_length=5, pattern=r"^\w{5}$"),
]

CodeEPCI: TypeAlias = CodeSiren

CodeDepartement: TypeAlias = Annotated[
    str,
    StringConstraints(min_length=2, max_length=3, pattern=r"^\w{2,3}$"),
]

CodeRegion: TypeAlias = Annotated[
    str,
    StringConstraints(min_length=2, max_length=2, pattern=r"^\d{2}$"),
]



from data_inclusion.schema.base import EnhancedEnum


class Frais(EnhancedEnum):
    GRATUIT = (
        "gratuit",
        "Gratuit",
        "Je peux accéder gratuitement au lieu et à ses services",
    )
    GRATUIT_SOUS_CONDITIONS = (
        "gratuit-sous-conditions",
        "Gratuit sous conditions",
        """
            La gratuité est conditionnée à des critères (situation familiale,
            convention avec un organisme social…)
        """,
    )
    PAYANT = (
        "payant",
        "Payant",
        "L’accès au lieu et/ou à ses services est payant",
    )
    ADHESION = (
        "adhesion",
        "Adhésion",
        "L’accès au lieu et/ou à ses services nécessite d’y adhérer",
    )
    PASS_NUMERIQUE = (
        "pass-numerique",
        "Accepte le pass numérique",
        "Il est possible d’utiliser un Pass numérique pour accéder au lieu",
    )



from data_inclusion.schema.base import EnhancedEnum


class LabelNational(EnhancedEnum):
    SOIXANTE_MILLE_REBONDS = (
        "60000-rebonds",
        "60 000 rebonds",
        None,
    )
    ACTION_LOGEMENT = (
        "action-logement",
        "Action logement",
        None,
    )
    ADIE = (
        "adie",
        "Adie",
        None,
    )
    AFPA = (
        "afpa",
        "AFPA",
        None,
    )
    AGEFIPH = (
        "agefiph",
        "AGEFIPH",
        None,
    )
    AIDANTS_CONNECT = (
        "aidants-connect",
        "Aidants Connect",
        None,
    )
    ALLIANCE_VILLES_EMPLOI = (
        "alliance-villes-emploi",
        "Alliance villes emploi",
        None,
    )
    ANLCI = (
        "anlci",
        "ANLCI",
        None,
    )
    APEC = (
        "apec",
        "APEC",
        None,
    )
    APELS = (
        "apels",
        "APELS Agence Pour l’Education par Le Sport",
        None,
    )
    APPRENTIS_DAUTEUIL = (
        "apprentis-dauteuil",
        "Apprentis d’Auteuil",
        None,
    )
    APTIC = (
        "aptic",
        "APTIC",
        None,
    )
    BANQUES_ALIMENTAIRES = (
        "banques-alimentaires",
        "Banques alimentaires",
        None,
    )
    BGE = (
        "bge",
        "BGE",
        None,
    )
    CAF = (
        "caf",
        "CAF",
        None,
    )
    CAMPUS_CONNECTE = (
        "campus-connecte",
        "Campus connecté",
        None,
    )
    CCI = (
        "cci",
        "CCI",
        None,
    )
    CHANTIER_ECOLE = (
        "chantier-ecole",
        "Chantier école",
        None,
    )
    CAP_EMPLOI_RESEAU_CHEOPS = (
        "cap-emploi-reseau-cheops",
        "CAP Emploi - Réseau CHEOPS",
        None,
    )
    CIDFF = (
        "cidff",
        "CIDFF",
        None,
    )
    CNAM = (
        "cnam",
        "CNAM",
        None,
    )
    COLLECTIF_EMPLOI = (
        "collectif-emploi",
        "Collectif emploi",
        None,
    )
    CONSEILLER_NUMERIQUE = (
        "conseiller-numerique",
        "Conseiller numérique",
        None,
    )
    COORACE = (
        "coorace",
        "Coorace",
        None,
    )
    CREPI = (
        "crepi",
        "CREPI",
        None,
    )
    CRESUS = (
        "cresus",
        "Crésus",
        None,
    )
    CROIX_ROUGE = (
        "croix-rouge",
        "Croix rouge",
        None,
    )
    DIHAL = (
        "dihal",
        "DIHAL",
        None,
    )
    DUO_FOR_A_JOB = (
        "duo-for-a-job",
        "Duo for a job",
        None,
    )
    ECOLES_DE_LA_DEUXIEME_CHANCE = (
        "ecoles-de-la-deuxieme-chance",
        "E2C - École de la 2e chance",
        None,
    )
    EGEE = (
        "egee",
        "EGEE",
        None,
    )
    EMMAUS = (
        "emmaus",
        "Emmaus",
        None,
    )
    ENVIE = (
        "envie",
        "Envie",
        None,
    )
    EPIDE = (
        "epide",
        "EPIDE",
        None,
    )
    ESPACE_EMPLOI_AGRIC_ARRCO = (
        "espace-emploi-agric-arrco",
        "Espace Emploi Agirc Arrco",
        None,
    )
    ETCLD = (
        "etcld",
        "Expérimentation territoriale contre le chômage de longue durée",
        None,
    )
    FABRIQUE_DE_TERRITOIRE = (
        "fabrique-de-territoire",
        "Fabrique de Territoire",
        None,
    )
    FACE = (
        "face",
        "Fondation FACE",
        None,
    )
    FEDE_PRO_FEM = (
        "fede-pro-fem",
        "Federation Professionnelle Pour les Femmes",
        None,
    )
    FEDERATION_DES_ACTEURS_DE_LA_SOLIDARITE = (
        "federation-des-acteurs-de-la-solidarite",
        "Fédération des acteurs de la solidarité",
        None,
    )
    FEDERATION_DES_ENTREPRISES_DINSERTION = (
        "federation-des-entreprises-dinsertion",
        "Fédération des entreprises d’insertion",
        None,
    )
    FORCE_FEMMES = (
        "force-femmes",
        "Force Femmes",
        None,
    )
    FRANCE_ACTIVE = (
        "france-active",
        "France Active",
        None,
    )
    FRANCE_SERVICE = (
        "france-service",
        "France service",
        None,
    )
    FRANCE_TRAVAIL = (
        "france-travail",
        "France Travail",
        None,
    )
    FRENCH_TECH = (
        "french-tech",
        "French Tech",
        None,
    )
    GEIQ = (
        "geiq",
        "GEIQ",
        None,
    )
    GRANDES_ECOLES_DU_NUMERIQUE = (
        "grandes-ecoles-du-numerique",
        "Grand Test Couveuse d’entreprise",
        None,
    )
    GRAND_TEST_COUVEUSE_DENTREPRISE = (
        "grand-test-couveuse-dentreprise",
        "Grandes écoles du numérique",
        None,
    )
    HUP = (
        "hup",
        "H’UP",
        None,
    )
    INAE = (
        "inae",
        "INAE",
        None,
    )
    INITIATIVE_FRANCE = (
        "initiative-france",
        "Initiative France",
        None,
    )
    KONEXIO = (
        "konexio",
        "Konexio",
        None,
    )
    LA_CRAVATE_SOLIDAIRE = (
        "la-cravate-solidaire",
        "La Cravate Solidaire",
        None,
    )
    LA_RESSOURCERIE = (
        "la-ressourcerie",
        "La ressourcerie",
        None,
    )
    LES_PREMIERES = (
        "les-premieres",
        "Les Premières",
        None,
    )
    LINKLUSION = (
        "linklusion",
        "Linklusion",
        None,
    )
    MAISONS_DE_LEMPLOI = (
        "maisons-de-lemploi",
        "Maisons de l’Emploi",
        None,
    )
    MDPH = (
        "mdph",
        "MDPH",
        None,
    )
    MISSION_LOCALE = (
        "mission-locale",
        "Mission Locale",
        None,
    )
    MOBIN = (
        "mobin",
        "Adhérent au Réseau Mob’In",
        None,
    )
    NQT = (
        "nqt",
        "NQT",
        None,
    )
    POINT_CONSEIL_BUDGET = (
        "point-conseil-budget",
        "Point conseil budget",
        None,
    )
    POINT_JUSTICE = (
        "point-justice",
        "Points Justice",
        None,
    )
    POSITIVE_PLANET = (
        "positive-planet",
        "Positive Planet",
        None,
    )
    PROXITE = (
        "proxite",
        "Proxité",
        None,
    )
    RESEAU_APP = (
        "reseau-app",
        "Réseau APP",
        None,
    )
    RESEAU_ENTREPRENDRE = (
        "reseau-entreprendre",
        "Réseau Entreprendre",
        None,
    )
    RESSOURCERIES = (
        "ressourceries",
        "Ressourceries",
        None,
    )
    RESTOS_DU_COEUR = (
        "restos-du-coeur",
        "Restos du coeur",
        None,
    )
    SCCONSEIL = (
        "scconseil",
        "SC Conseil",
        None,
    )
    SECOURS_POPULAIRE = (
        "secours-populaire",
        "Secours populaire",
        None,
    )
    SIAO = (
        "siao",
        "SIAO",
        None,
    )
    SIMPLON = (
        "simplon",
        "Simplon",
        None,
    )
    SINCA = (
        "sinca",
        "SINGA",
        None,
    )
    SNC = (
        "snc",
        "SNC - Solidarité Nouvelle Face au Chômage",
        None,
    )
    SPORT_DANS_LA_VILLE = (
        "sport-dans-la-ville",
        "Sport Dans La Ville",
        None,
    )
    TOUS_TES_POSSIBLE = (
        "tous-tes-possible",
        "Tous Tes Possibles",
        None,
    )
    TZCLD = (
        "tzcld",
        "TZCLD - Territoire Zero Chomeur Longue Durée",
        None,
    )
    UNAF = (
        "unaf",
        "Union nationale de l’aide aux familles",
        None,
    )
    UNAI = (
        "unai",
        "UNAI",
        None,
    )
    UNCCAS = (
        "unccas",
        "Union nationale des centres communaux d’action sociale",
        None,
    )
    UNEA = (
        "unea",
        "UNEA",
        None,
    )
    UNIS_CITE = (
        "unis-cite",
        "Unis-Cité",
        None,
    )
    WIMOOV = (
        "wimoov",
        "Wimoov",
        None,
    )
